<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>MEConfig</name>
    <message>
        <location filename="../mainwindow.ui" line="26"/>
        <source>MX User Manager</source>
        <translation>MX Benutzer-Manager</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Administration</source>
        <translation>Administration</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="65"/>
        <source>Add a new user</source>
        <translation>Einen neuen Benutzer hinzufügen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Add User Account</source>
        <translation>Benutzerkonto hinzufügen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="132"/>
        <source>Enter password for new user</source>
        <translation>Passwort für den neuen Benutzer eintragen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="141"/>
        <source>password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="173"/>
        <source>Reenter password for new user</source>
        <translation>Passwort des neuen Benutzers noch einmal eintragen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <source>confirm password</source>
        <translation>Passwort bestätigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>Username of new user</source>
        <translation>Benutzername des neuen Benutzers</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="201"/>
        <source>User login name:</source>
        <translation>Anmeldename des Benutzers:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <location filename="../mainwindow.ui" line="466"/>
        <source>Enter username of new user</source>
        <translation>Benutzernamen des neuen Benutzers eintragen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="223"/>
        <location filename="../mainwindow.ui" line="472"/>
        <source>username</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="239"/>
        <location filename="../mainwindow.ui" line="258"/>
        <source>Password for new user</source>
        <translation>Passwort für den neuen Benutzer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="242"/>
        <source>Confirm user password:</source>
        <translation>Benutzerpasswort bestätigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>User password:</source>
        <translation>Benutzerpasswort</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="271"/>
        <source>Grant this user administrative rights to the system (sudo)</source>
        <translation>Diesem Benutzer Verwaltungsrechte für das System (sudo) gewähren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="290"/>
        <source>Delete User Account</source>
        <translation>Benutzerkonto löschen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>Select user</source>
        <translation>Benutzer wählen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="349"/>
        <location filename="../mainwindow.ui" line="1436"/>
        <source>Select user to delete</source>
        <translation>Benutzerkonto auswählen, das gelöscht werden soll</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>User to delete:</source>
        <translation>Benutzer zu löschen:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="374"/>
        <source>Also delete the user&apos;s home directory</source>
        <translation>Home-Verzeichnis des Benutzers auch löschen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="377"/>
        <source>Delete user home directory</source>
        <translation>Home-Verzeichnis des Benutzers löschen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="396"/>
        <source>Rename User Account</source>
        <translation>Benutzerkonto umbenennen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <location filename="../mainwindow.ui" line="570"/>
        <source>Select user to modify:</source>
        <translation>Benutzer auswählen, der geändert werden soll:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="450"/>
        <source>New user name:</source>
        <translation>Neuer Benutzername: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="491"/>
        <source>Change User Password</source>
        <translation>Benutzerpasswort ändern</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="519"/>
        <source>new password</source>
        <translation>Neues Passwort</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="535"/>
        <source>Confirm new password:</source>
        <translation>Neues Passwort bestätigen:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="554"/>
        <source>confirm new password</source>
        <translation>Neues Passwort bestätigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="586"/>
        <source>New user password:</source>
        <translation>Neues Benutzerpasswort:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="620"/>
        <source>Options</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="623"/>
        <source>Repair a user configuration</source>
        <translation>Benutzerkonfiguration reparieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="657"/>
        <location filename="../mainwindow.ui" line="1393"/>
        <source>Modify User Account</source>
        <translation>Benutzerkonto ändern</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="669"/>
        <location filename="../mainwindow.ui" line="685"/>
        <source>Select user to repair</source>
        <translation>Auswählen des Benutzerkontos, das repariert werden soll</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="672"/>
        <location filename="../mainwindow.ui" line="1445"/>
        <source>User to change:</source>
        <translation>Benutzerkonto zum Ändern:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="717"/>
        <source>Restore Defaults</source>
        <translation>Voreinstellungen wiederherstellen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="738"/>
        <source>Restore browser configs to MX defaults</source>
        <translation>Browser-Einstellungen gemäss MX-Voreinstellungen wiederherstellen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="744"/>
        <source>Mozilla (Iceweasel or Firefox) configs</source>
        <translation>Mozilla (Iceweasel or Firefox)  Konfiguration</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="747"/>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="754"/>
        <source>Restore group memberships to MX defaults</source>
        <translation>Gruppenzugehörigkeiten gemäss MX Voreinstellungen wiederherstellen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="760"/>
        <source>Group memberships</source>
        <translation>Gruppenzugehörigkeiten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="763"/>
        <source>Alt+G</source>
        <translation>Alt+G</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="773"/>
        <source>Change Autologin Settings</source>
        <translation>Anmeldeeinstellungen ändern</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="779"/>
        <source>Log in automatically</source>
        <translation>Automatische Anmeldung</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="786"/>
        <source>Require password to log in</source>
        <translation>Ein Passwort bei der Anmeldung fordern</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="801"/>
        <source>Copy/Sync</source>
        <translation>Kopieren/Synchronisieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="828"/>
        <source>Copy Between Desktops</source>
        <translation>Kopieren zwischen Arbeitsoberflächen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="855"/>
        <location filename="../mainwindow.ui" line="922"/>
        <source>Select desktop to copy from</source>
        <translation>Die Arbeitsoberfläche wählen, von der aus kopiert werden soll</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="868"/>
        <source>Select to only copy files</source>
        <translation>Auswahl: nur Dateien kopieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="871"/>
        <source>Copy only</source>
        <translation>Nur Kopieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="887"/>
        <location filename="../mainwindow.ui" line="900"/>
        <source>Select desktop to copy to</source>
        <translation>Die Arbeitsoberfläche wählen, auf die kopiert werden soll</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="909"/>
        <source>Copy to:</source>
        <translation>Kopieren auf:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="931"/>
        <source>Copy from:</source>
        <translation>Kopieren von:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="944"/>
        <source>Select to copy and then delete differences</source>
        <translation>Kopieren auswählen und dann die Unterschiede löschen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="947"/>
        <source>Sync</source>
        <translation>Synchronisieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="993"/>
        <source>Select to copy/sync Shared</source>
        <translation>Freigegebene Ordner kopieren /synchronisieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="996"/>
        <source>Shared folder</source>
        <translation>Freigegebene Ordner</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1009"/>
        <source>Select to copy/sync entire home</source>
        <translation>Gesamtes Home-Verzeichnis kopieren / synchronisieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1012"/>
        <source>Entire home</source>
        <translation>Gesamtes Home-Verzeichnis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1028"/>
        <source>Select to copy/sync the browser configuration</source>
        <translation>Wählen, um die Browser-Konfiguration zu kopieren/synchronisieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1031"/>
        <source>Mozilla (Firefox or Iceweasel) configs</source>
        <translation>Mozilla (Firefox oder Iceweasel)  Konfiguration</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1044"/>
        <source>Select to copy/sync Documents</source>
        <translation>Dokumente kopieren/synchronisieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1047"/>
        <source>Documents folder</source>
        <translation>Dokumente-Ordner</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1054"/>
        <source>What to copy/sync:</source>
        <translation>Was soll kopiert/synchronisiert werden:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1070"/>
        <source>Progress</source>
        <translation>Verlauf</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1100"/>
        <location filename="../mainwindow.ui" line="1116"/>
        <source>Status of the changes</source>
        <translation>Status der Änderungen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1119"/>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1135"/>
        <source>Progress of the changes</source>
        <translation>Verlauf der Änderungen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1172"/>
        <source>Add/Remove Groups</source>
        <translation>Gruppen hinzufügen/löschen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1184"/>
        <source>Add Group</source>
        <translation>Gruppe hinzufügen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1211"/>
        <source>Enter name of new group</source>
        <translation>Name der neuen Gruppe eingeben</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1217"/>
        <source>groupname</source>
        <translation>Gruppenname</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1227"/>
        <source>Create a group with GID &gt; 1000</source>
        <translation>Eine Gruppe mit GID &gt; 1000 anlegen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1230"/>
        <source>Create a user-level group</source>
        <translation>Eine Gruppe auf Benutzerebene erstellen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1259"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Enter name of new group&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Name der neuen Gruppe eingeben&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1262"/>
        <source>Group name:</source>
        <translation>Gruppenname:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1281"/>
        <source>Delete Group</source>
        <translation>Gruppe löschen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1350"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select group to delete&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Zu entfernende Gruppe auswählen&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1359"/>
        <source>Select group to delete:</source>
        <translation>Zu löschende Gruppe auswählen:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1366"/>
        <source>*Please doublecheck your selections before applying, removing a wrong group can break your system.</source>
        <translation>*Bitte die Auswahl sorgfältig überprüfen, denn das Entfernen einer falschen Gruppe kann Ihr System zerstören.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1381"/>
        <source>Group Membership</source>
        <translation>Gruppenzugehörigkeit</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1455"/>
        <source>Groups user belongs to (change the groups by selecting/deselecting the appropriate boxes):</source>
        <translation>Gruppenzugehörigkeit des Benutzers (Gruppzugehörigkeit ändern, indem die entsprechenden Kästchen markiert werden oder nicht):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1478"/>
        <source>*Please doublecheck your selections before applying, assigning wrong group memberships can break your system. If you made a mistake, use restore group membership in Options tab to restore the defaults.</source>
        <translation>*Bitte die Auswahl sorgfältig überprüfen, da die Zuweisung falscher Gruppenmitgliedschaften Ihr System zerstören kann. Falls Sie einen Fehler gemacht haben, verwenden Sie die Funktion &quot;Gruppenmitgliedschaft wiederherstellen&quot; auf der Registerkarte &quot;Optionen&quot;, um die Standardeinstellungen wiederherzustellen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1507"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Select user to change&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Den zu ändernden Benutzer wählen&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1583"/>
        <source>Cancel any changes then quit</source>
        <translation>Änderungen zurückziehen und dann den Vorgang beenden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1586"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1593"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1634"/>
        <source>Display help </source>
        <translation>Hilfe anzeigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1637"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1644"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1651"/>
        <source>Apply any changes</source>
        <translation>Alle Änderungen akzeptieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1654"/>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1661"/>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1668"/>
        <source>About this application</source>
        <translation>Über diese Anwendung</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1671"/>
        <source>About...</source>
        <translation>Über...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1678"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="157"/>
        <location filename="../mainwindow.cpp" line="165"/>
        <location filename="../mainwindow.cpp" line="192"/>
        <location filename="../mainwindow.cpp" line="781"/>
        <location filename="../mainwindow.cpp" line="811"/>
        <location filename="../mainwindow.cpp" line="968"/>
        <location filename="../mainwindow.cpp" line="1035"/>
        <location filename="../mainwindow.cpp" line="1042"/>
        <location filename="../mainwindow.cpp" line="1047"/>
        <location filename="../mainwindow.cpp" line="1052"/>
        <location filename="../mainwindow.cpp" line="1057"/>
        <source>none</source>
        <translation>keine</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="142"/>
        <location filename="../mainwindow.cpp" line="745"/>
        <location filename="../mainwindow.cpp" line="975"/>
        <location filename="../mainwindow.cpp" line="984"/>
        <source>browse...</source>
        <translation>Durchsuchen...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="208"/>
        <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
        <translation>Die Benutzerkonfiguration wird repariert werden. Schlieẞen Sie jetzt bitte alle anderen Anwendungen. Nach der Reparatur bitte abmelden oder neu starten.  Sind Sie sicher, daẞ Sie jetzt reparieren wollen?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="230"/>
        <source>User group membership was restored.</source>
        <translation>Die Mitgliedschaft bei der Nutzergruppe wurde wiederhergestellt.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="235"/>
        <source>Mozilla settings were reset.</source>
        <translation>Die Einstellungen für Mozilla wurden zurückgesetzt.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="246"/>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>Autologin options</source>
        <translation>Optionen für das automatische Anmelden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="247"/>
        <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
        <translation>Automatische Anmeldung ist ausgeschaltet für den Benutzer &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
        <translation>Automatische Anmeldung ist eingeschaltet für den Benutzer &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="274"/>
        <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
        <translation>Ein Ziel für das &apos;Kopieren zu&apos; muss angegeben werden.  Es ist nicht möglich, zur Arbeitsoberfläche, auf der Sie angemeldet sind, zu kopieren.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="280"/>
        <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
        <translation>Schließen Sie alle anderen Programme, bevor Sie kopieren.  Stellen Sie sicher, daß das Ziel genügend Platz bietet, um die zu kopierenden Dateien aufzunehmen.  Das Kopieren zwischen Arbeitsoberfläche kann Dateien oder Einstellungen der Ziel-Arbeitsoberfläche überschreiben oder zerstören.  Sind Sie sicher, daẞ Sie weitermachen wollen? </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>Synchronizing desktop...</source>
        <translation>Die Arbeitsoberfläche wird synchronisiert...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>Copying desktop...</source>
        <translation>Die Arbeitsoberfläche wird kopiert...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="345"/>
        <location filename="../mainwindow.cpp" line="577"/>
        <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Der Benutzername muss mindestens 2 Zeichen enthalten.  Wählen Sie bitte einen längeren Benutzernamen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="350"/>
        <source>The user name cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Der Benutzername darf keine Sonderzeichen oder Leerzeichen enthalten.
Bitte wählen Sie einen anderen Namen, bevor Sie fortfahren.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="356"/>
        <source>Sorry, this name is in use. Please enter a different name.</source>
        <translation>Dieser Name ist bereits vergeben. Bitte einen anderen Namen wählen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <location filename="../mainwindow.cpp" line="415"/>
        <source>Password entries do not match. Please try again.</source>
        <translation>Die eingetragenen Passwörter gleichen sich nicht.  Versuchen Sie es bitte noch einmal.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <location filename="../mainwindow.cpp" line="420"/>
        <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
        <translation>Das Benutzerpasswort muss mindestens 2 Zeichen lang sein. Bitte wählen Sie ein längeres Passwort, bevor Sie fortfahren.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="404"/>
        <source>The user was added ok.</source>
        <translation>Der Benutzer ist erfolgreich hinzugefügt worden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="407"/>
        <source>Failed to add the user.</source>
        <translation>Der Benutzer konnte nicht hinzugefügt werden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="435"/>
        <source>Password successfully changed.</source>
        <translation>Passwort erfolgreich geändert.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="438"/>
        <source>Failed to change password.</source>
        <translation>Änderung des Passworts fehlgeschlagen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="444"/>
        <source>This action cannot be undone. Are you sure you want to delete user %1?</source>
        <translation>Diese Aktion kann nicht widerrufen werden.  Sind Sie sicher, daẞ Sie den Benutzer %1 löschen wollen?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="463"/>
        <source>The user has been deleted.</source>
        <translation>Der Benutzer ist gelöscht worden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="465"/>
        <source>Failed to delete the user.</source>
        <translation>Der Benutzer konnte nicht gelöscht werden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="479"/>
        <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
        <translation>Der Gruppenname muss mindestens 2 Zeichen enthalten.  Wählen Sie bitte einen längeren Namen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="484"/>
        <source>The group name needs to be lower case and it 
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Der Gruppename muss klein geschrieben werden und 
darf keine Sonderzeichen oder Leerzeichen enthalten.
Bitte wählen Sie einen anderen Namen, bevor Sie weitermachen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="492"/>
        <source>Sorry, that group name already exists. Please enter a different name.</source>
        <translation>Dieser Gruppenname ist bereits vergeben. Bitte einen anderen Namen für diese Gruppe wählen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="500"/>
        <source>The system group was added ok.</source>
        <translation>Die Systemgruppe ist erfolgreich hinzugefügt worden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="502"/>
        <source>Failed to add the system group.</source>
        <translation>Die Systemgruppe konnte nicht hinzugefügt werden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="517"/>
        <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
        <translation>Diese Aktion kann nicht rückgängig gemacht werden.  Sind Sie sicher, daẞ Sie die Gruppe %1 löschen wollen?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="518"/>
        <source>This action cannot be undone. Are you sure you want to delete the following groups: %1?</source>
        <translation>Dieser Vorgang kann nicht rückgängig gemacht werden. Sind Sie sicher, daẞ Sie die folgenden Gruppen löschen wollen: %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="527"/>
        <source>Failed to delete the group.</source>
        <translation>Die Gruppe konnte nicht gelöscht werden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="527"/>
        <source>Group: %1</source>
        <translation>Gruppe: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="531"/>
        <source>The group has been deleted.</source>
        <translation>Die Gruppe ist gelöscht worden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="531"/>
        <source>The groups have been deleted.</source>
        <translation>Die Gruppen wurden entfernt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="548"/>
        <source>The changes have been applied.</source>
        <translation>Die Änderungen wurden übernommen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="550"/>
        <source>Failed to apply group changes</source>
        <translation>Die Änderungen an der Gruppe konnten nicht ausgeführt werden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="568"/>
        <source>The selected user name is currently in use.</source>
        <translation>Der angegebene Benutzername wird gerade schon verwendet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="569"/>
        <source>To rename this user, please log out and log back in using another user account.</source>
        <translation>Um diesen Benutzer umzubenennen bitte ausloggen und mit einem anderen Benutzerkonto wieder einloggen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="582"/>
        <source>The user name needs to be lower case and it
cannot contain special characters or spaces.
Please choose another name before proceeding.</source>
        <translation>Der Gruppename muss klein geschrieben werden und 
darf keine Sonderzeichen oder Leerzeichen enthalten.
Bitte wählen Sie einen anderen Namen, bevor Sie weitermachen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="589"/>
        <source>Sorry, this name already exists on your system. Please enter a different name.</source>
        <translation>Dieser Name existiert bereits auf dem System. Bitte einen anderen Namen wählen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="598"/>
        <source>Failed to rename the user. Please make sure that the user is not logged in, you might need to restart</source>
        <translation>Umbenennen des Benutzers fehlgeschlagen. Bitte stellen Sie sicher, daß dieser Benutzer nicht eingeloggt ist. Eventuell ist auch ein Neustart des Rechners nötig.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="622"/>
        <source>The user was renamed.</source>
        <translation>Der Benutzer ist jetzt umbenannt.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="634"/>
        <location filename="../mainwindow.cpp" line="662"/>
        <source>Synchronizing desktop...ok</source>
        <translation>Die Arbeitsoberfläche wird synchronisiert...   Erfolgreich</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="636"/>
        <location filename="../mainwindow.cpp" line="664"/>
        <source>Copying desktop...ok</source>
        <translation>Die Arbeitsoberfläche wird kopiert...Erfolgreich</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="668"/>
        <source>Synchronizing desktop...failed</source>
        <translation>Die Arbeitsoberfläche wird synchronisiert...fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="670"/>
        <source>Copying desktop...failed</source>
        <translation>Die Arbeitsoberfläche wird kopiert...fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="689"/>
        <source>Confirmation</source>
        <translation>Bestätigung</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="690"/>
        <source>Process not done. Are you sure you want to quit the application?</source>
        <translation>Der Prozess ist nicht abgeschlossen. Wollen Sie das Programm wirklich beenden?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="940"/>
        <source>About %1</source>
        <translation>Über %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="941"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="942"/>
        <source>Simple user configuration for MX Linux</source>
        <translation>Einfache Benutzer-Konfiguration für MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="944"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="945"/>
        <source>%1 License</source>
        <translation>%1 Lizenz</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="959"/>
        <source>%1 Help</source>
        <translation>%1 Hilfe</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="976"/>
        <source>Select folder to copy to</source>
        <translation>Zielordner für Kopie auswählen</translation>
    </message>
</context>
<context>
    <name>PassEdit</name>
    <message>
        <location filename="../passedit.cpp" line="162"/>
        <source>Negligible</source>
        <translation>Minimal</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="162"/>
        <source>Very weak</source>
        <translation>Sehr schwach</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="162"/>
        <source>Weak</source>
        <translation>Schwach</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="163"/>
        <source>Moderate</source>
        <translation>Mittel</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="163"/>
        <source>Strong</source>
        <translation>Stark</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="163"/>
        <source>Very strong</source>
        <translation>Sehr stark</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="164"/>
        <source>Password strength: %1</source>
        <translation>Passwortstärke: %1</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="200"/>
        <source>Hide the password</source>
        <translation>Passwort verbergen</translation>
    </message>
    <message>
        <location filename="../passedit.cpp" line="200"/>
        <source>Show the password</source>
        <translation>Passwort anzeigen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="50"/>
        <source>License</source>
        <translation>Lizenz</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <location filename="../about.cpp" line="61"/>
        <source>Changelog</source>
        <translation>Änderungsprotokoll</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="65"/>
        <location filename="../main.cpp" line="73"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Sie sind als Administrator am System angemeldet. Bitte melden Sie sich ab und dann als normaler Benutzer wieder an, um dieses Programm zu verwenden.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>You must run this program with admin access.</source>
        <translation>Diese Anwendung muss mit Administratorrechten ausgeführt werden.</translation>
    </message>
</context>
</TS>
